@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "La sol·licitud ha fallat, Nextcloud és actualment en mode de manteniment!",
     "Unread articles" : "Articles sense llegir",
     "News" : "Notí­cies",
+    "Shared with me" : "Compartit amb mi",
     "An RSS/Atom feed reader" : "Un lector de notícies RSS/Atom",
     "Use system cron for updates" : "Feu servir el sistema cron per a les actualitzacions",
     "Purge interval" : "Interval de purga",
@@ -35,6 +36,7 @@ OC.L10N.register(
     "Unstar article" : "Deixa de destacar l'article",
     "Keep article unread" : "Manté l'article com a no llegit",
     "Remove keep article unread" : "Elimineu mantenir l'article no llegit",
+    "Share" : "Compartir",
     "Username" : "Nom d'usuari",
     "by" : "per",
     "from" : "des de",
@@ -55,10 +57,9 @@ OC.L10N.register(
     "Refresh" : "Refresca",
     "Load next feed" : "Carrega la font següent",
     "Load previous feed" : "Carrega la font anterior",
-    "Load next folder" : "Carrega la carpeta següent",
     "Load previous folder" : "Carrega la carpeta anterior",
+    "Load next folder" : "Carrega la carpeta següent",
     "Scroll to active navigation entry" : "Desplaça per activar l'entrada de navegació",
-    "Focus search field" : "Camp de cerca de focus",
     "Mark current article's feed/folder read" : "Marca com a llegida la font/carpeta de l'article actual",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "S'ha detectat el mode Ajax o webcron. Les vostres fonts no s'actualitzaran!",
     "How to set up the operating system cron" : "Com configurar el cron del sistema operatiu",
