@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Request failed, Nextcloud is in currently in maintenance mode!",
     "Unread articles" : "Unread articles",
     "News" : "News",
+    "Shared with me" : "Shared with me",
     "An RSS/Atom feed reader" : "An RSS/Atom feed reader",
     "Use system cron for updates" : "Use system cron for updates",
     "Purge interval" : "Purge interval",
@@ -26,6 +27,7 @@ OC.L10N.register(
     "Unstar article" : "Unstar article",
     "Keep article unread" : "Keep article unread",
     "Remove keep article unread" : "Remove keep article unread",
+    "Share" : "Share",
     "Username" : "Username",
     "by" : "by",
     "from" : "from",
@@ -46,10 +48,9 @@ OC.L10N.register(
     "Refresh" : "Refresh",
     "Load next feed" : "Load next feed",
     "Load previous feed" : "Load previous feed",
-    "Load next folder" : "Load next folder",
     "Load previous folder" : "Load previous folder",
+    "Load next folder" : "Load next folder",
     "Scroll to active navigation entry" : "Scroll to active navigation entry",
-    "Focus search field" : "Focus search field",
     "Mark current article's feed/folder read" : "Mark current article's feed/folder read",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax or webcron mode detected! Your feeds will not be updated!",
     "How to set up the operating system cron" : "How to set up the operating system cron",
