@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "¡Se presentó una falla en la solicitud, por el momento Nextcloud se encuentra en modo mantenimiento!",
     "Unread articles" : "Artículos sin leer",
     "News" : "Noticias",
+    "Shared with me" : "Compartido conmigo",
     "Use system cron for updates" : "Usa el cron del sistema para las actualizaciones",
     "Purge interval" : "Intervalo de purga",
     "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
@@ -25,6 +26,7 @@ OC.L10N.register(
     "Unstar article" : "Desmarcar artículo",
     "Keep article unread" : "Mantener el artículo como no-leído",
     "Remove keep article unread" : "Eliminar mantener artículo como no leído",
+    "Share" : "Compartir",
     "Username" : "Usuario",
     "by" : "por",
     "from" : "de",
@@ -45,10 +47,9 @@ OC.L10N.register(
     "Refresh" : "Actualizar",
     "Load next feed" : "Cargar la siguiente fuente ",
     "Load previous feed" : "Cargar fuente anterior",
-    "Load next folder" : "Cargar la siguiente carpeta",
     "Load previous folder" : "Cargar carpeta anterrior",
+    "Load next folder" : "Cargar la siguiente carpeta",
     "Scroll to active navigation entry" : "Desplázate hasta el elemento de navegación activo",
-    "Focus search field" : "Ir al campo de búsqueda",
     "Mark current article's feed/folder read" : "Marcar la fuente/carpeta del artículo actual como leído",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "¡Se ha detectado el modo Ajax o webron! ¡Tus fuentes no serán actualizadas!",
     "How to set up the operating system cron" : "Cómo establecer las tareas programadas del sistema operativo",
@@ -109,4 +110,4 @@ OC.L10N.register(
     "Documentation" : "Documentación",
     "Report a bug" : "Reportar una falla"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
