@@ -111,4 +111,4 @@ OC.L10N.register(
     "Documentation" : "Documentación",
     "Report a bug" : "Reportar una falla"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
