@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "הבקשה נכשלה, מערכת Nextcloud נמצאת כרגע במצב תחזוקה!",
     "Unread articles" : "מאמרים שלא נקראו",
     "News" : "חדשות",
+    "Shared with me" : "משותף אתי",
     "An RSS/Atom feed reader" : "קורא ערוצי תוכן מסוג RSS/Atom",
     "Use system cron for updates" : "שימוש ב־cron של המערכת לעדכונים",
     "Purge interval" : "מרווח להסרה ממסד הנתונים",
@@ -27,6 +28,7 @@ OC.L10N.register(
     "Unstar article" : "הסרת סימון כוכב ממאמר",
     "Keep article unread" : "השארת מאמר עם סימון לא נקרא",
     "Remove keep article unread" : "ביטול השארת מאמר עם סימון לא נקרא",
+    "Share" : "שתף",
     "Username" : "שם משתמש",
     "No users found" : "לא נמצאו משתמשים",
     "by" : "על ידי",
@@ -48,10 +50,9 @@ OC.L10N.register(
     "Refresh" : "רענון",
     "Load next feed" : "טעינת הזנת תוכן הבאה",
     "Load previous feed" : "טעינת הזנת תוכן קודמת",
-    "Load next folder" : "טעינת תיקייה הבאה",
     "Load previous folder" : "טעינת תיקייה קודמת",
+    "Load next folder" : "טעינת תיקייה הבאה",
     "Scroll to active navigation entry" : "גלילה לרשומת ניווט פעילה",
-    "Focus search field" : "מיקוד שדה חיפוש",
     "Mark current article's feed/folder read" : "סימון ערוץ מידע/תיקייה למאמר הנוכחי כנקראו",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "זוהה מצב Ajax או webcron! ערוצי התוכן שלך לא יעודכנו!",
     "How to set up the operating system cron" : "איך להגדיר את cron מערכת ההפעלה",
