@@ -7,7 +7,9 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Token-i ka skaduar ose s’është aktivizuar aplikacioni! Ringarkoni faqen!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Gabim i brendshëm serveri! Ju lutemi kontrolloni skedarin tuaj data/nextcloud.log për informacion shtesë!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Kërkesa dështoi, Nextcloud është aktualisht më gjëndjen e mirëmbajtjes!",
+    "Unread articles" : "Artikujt e palexuar",
     "News" : "Lajme",
+    "Shared with me" : "Ndarë me mua",
     "Use system cron for updates" : "Përdor sistemin cron për përditësime",
     "Purge interval" : "Interval pastrimi",
     "Maximum read count per feed" : "Numër maksimum leximesh për prurje",
@@ -24,6 +26,8 @@ OC.L10N.register(
     "Unstar article" : "Hiqja yllin artikullit",
     "Keep article unread" : "Mbaje artikullin si të palexuar",
     "Remove keep article unread" : "Hiqi gjendjen mbaje artikullin të palexuar",
+    "Share" : "Shpërndaje",
+    "Username" : "Emër përdoruesi",
     "by" : "nga",
     "from" : "nga",
     "Play audio" : "Luaje audion",
@@ -43,10 +47,9 @@ OC.L10N.register(
     "Refresh" : "Rifreskoje",
     "Load next feed" : "Ngarko prurjen pasuese",
     "Load previous feed" : "Ngarko prurjen e mëparshme",
-    "Load next folder" : "Ngarko dosjen pasuese",
     "Load previous folder" : "Ngarko dosjen e mëparshme",
+    "Load next folder" : "Ngarko dosjen pasuese",
     "Scroll to active navigation entry" : "Rrëshqiteni që të aktivizohet lëvizja për elementin",
-    "Focus search field" : "Kaloje fokusin te fusha e kërkimeve",
     "Mark current article's feed/folder read" : "Shënoje prurjen/dosjen e artikullit të tanishëm si të lexuar",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zbulohet modaliteti Ajax ose webcron! Feedet tuaja nuk do të përditësohen!",
     "How to set up the operating system cron" : "Si të rregullohet cron-i i sistemit operativ",
@@ -62,7 +65,6 @@ OC.L10N.register(
     "Folder exists already!" : "Ka një dosje të tillë!",
     "Credentials" : "Kredenciale",
     "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Kredencialet HTTP Basic Auth duhet të depozitohen të pafshehtëzuara! Cilido që ka hyrje te shërbyesi ose te baza e të dhënave do të jetë në gjendje të hyjë në to!",
-    "Username" : "Emër përdoruesi",
     "Password" : "Fjalëkalim",
     "New Folder" : "Dosje e Re",
     "Create" : "Krijoje",
@@ -89,7 +91,6 @@ OC.L10N.register(
     "Deleted folder" : "Dosja u fshi",
     "Undo delete folder" : "Zhbëje fshirjen e dosjes",
     "Starred" : "Me yll",
-    "Unread articles" : "Artikujt e palexuar",
     "All articles" : "Krejt artikujt",
     "Settings" : "Rregullimet",
     "Disable mark read through scrolling" : "Çaktivizo shënime si të lexuar gjatë rrëshqitjesh",
