@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Неуспео захтев. Некстклауд сервер је тренутно у режиму приступа само једног корисника!",
     "Unread articles" : "Непрочитани чланци",
     "News" : "Вести",
+    "Shared with me" : "Дељено са мном",
     "An RSS/Atom feed reader" : "RSS/Atom читач довода",
     "Use system cron for updates" : "Користи системски крон за ажурирања",
     "Purge interval" : "Интервал чишћења",
@@ -35,6 +36,7 @@ OC.L10N.register(
     "Unstar article" : "Скини звездицу чланку",
     "Keep article unread" : "Остави чланак непрочитаним",
     "Remove keep article unread" : "Уклони да остане непрочитан",
+    "Share" : "Подели",
     "Username" : "Корисничко име",
     "by" : "од",
     "from" : "од",
@@ -55,10 +57,9 @@ OC.L10N.register(
     "Refresh" : "Освежи",
     "Load next feed" : "Учитај следећи довод",
     "Load previous feed" : "Учитај претходни довод",
-    "Load next folder" : "Учитај следећу фасциклу",
     "Load previous folder" : "Учитај претходну фасциклу",
+    "Load next folder" : "Учитај следећу фасциклу",
     "Scroll to active navigation entry" : "Отклизај до активног уноса",
-    "Focus search field" : "Фокусирај на поље за претрагу",
     "Mark current article's feed/folder read" : "Означи доводе/фасцикле тренутног чланка прочитаним",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Детектован Ajax или webcron начин рада! Доводи неће бити ажурирани!",
     "How to set up the operating system cron" : "Како подестити крон оперативног система",
