@@ -1,25 +1,33 @@
 OC.L10N.register(
     "news",
     {
-    "Request failed, network connection unavailable!" : "Begäran misslyckades, nätverksanslutning otillgänglig!",
+    "Request failed, network connection unavailable!" : "Förfrågan misslyckades, nätverksanslutning otillgänglig!",
     "Request unauthorized. Are you logged in?" : "Ogiltig begäran. Är du inloggad?",
-    "Request forbidden. Are you an admin?" : "Begäran förbjuden. Är du administratör?",
+    "Request forbidden. Are you an admin?" : "Förfrågan förbjuden. Är du administratör?",
     "Token expired or app not enabled! Reload the page!" : "Polletten föråldrad eller så är applikationen inte aktiverad! Uppdatera sidan.",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Internt serverfel! Vänligen kontrollera din loggfil under data/nextcloud.log för mer information!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Förfrågan misslyckades. Nextcloud är för närvarande i underhållsläge!",
+    "News feeds" : "Nyhetsflöden",
     "Unread articles" : "Olästa artiklar",
     "News" : "Nyheter",
+    "News folders" : "Nyhetsmappar",
     "Shared with me" : "Delad med mig",
     "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
     "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
+    "Disable this if you use a custom updater." : "Slå av detta om du anväder en egen uppdateringsprocess.",
     "Purge interval" : "Utrensningsintervall",
     "Maximum read count per feed" : "Maximalt läsantal per flöde",
     "Maximum redirects" : "Maximala omdirigeringar",
     "Feed fetcher timeout" : "Timeout för flödes-hämtare",
     "Explore Service URL" : "Utforska tjänstwebbadress",
+    "For more information check the wiki." : "Se wikin för mer information.",
+    "Update interval" : "Uppdateringsintervall",
+    "Interval in seconds in which the feeds will be updated." : "Antal sekunder mellan uppdateringar av flödena.",
+    "For more information check the documentation." : "Se dokumentationen för mer information.",
     "Saved" : "Sparad",
     "Download" : "Hämta",
     "Close" : "Stäng",
+    "Subscribe to" : "Prenumerera på",
     "No articles available" : "Inga artiklar tillgängliga",
     "No unread articles available" : "Inga olästa artiklar tillgängliga",
     "Open website" : "Öppna webbplats",
@@ -28,17 +36,23 @@ OC.L10N.register(
     "Keep article unread" : "Behåll artikel oläst",
     "Remove keep article unread" : "Ta bort behåll artikel oläst",
     "Share" : "Dela",
+    "Share with users" : "Dela med användare",
     "Username" : "Användarnamn",
     "No users found" : "Inga användare hittades",
+    "Error while searching for users" : "Kunde inte söka bland användare",
+    "Share on social media" : "Dela via sociala medier",
+    "I wanted you to see this article" : "Jag vill rekommendera dig den här artikeln",
+    "Check out this article" : "Spana in den här artikeln",
     "by" : "av",
     "from" : "från",
+    "shared by" : "delad av",
     "Play audio" : "Spela ljud",
     "Download audio" : "Hämta ljud",
     "Download video" : "Hämta video",
     "Keyboard shortcut" : "Tangentbordsgenvägar",
     "Description" : "Beskrivning",
     "right" : "Höger",
-    "Jump to next article" : "Hoppa till nästkommande artikel",
+    "Jump to next article" : "Hoppa till nästa artikel",
     "left" : "vänster",
     "Jump to previous article" : "Hoppa till föregående artikel",
     "Toggle star article" : "Växla stjärnmärkning av artiklar",
