@@ -21,6 +21,7 @@ OC.L10N.register(
     "Unstar article" : "Зняти позначку статті",
     "Keep article unread" : "Залишити статтю непрочитаною",
     "Remove keep article unread" : "Позначити статтю як прочитану",
+    "Share" : "Поділитися",
     "Username" : "Ім'я користувача",
     "by" : "по",
     "from" : "З",
@@ -41,10 +42,9 @@ OC.L10N.register(
     "Refresh" : "Оновити",
     "Load next feed" : "Завантажити наступну стрічку",
     "Load previous feed" : "Завантажити попередню стрічку",
-    "Load next folder" : "Завантажити наступну теку",
     "Load previous folder" : "Завантажити попередню теку",
+    "Load next folder" : "Завантажити наступну теку",
     "Scroll to active navigation entry" : "Перехід до обраного елементу",
-    "Focus search field" : "Поставити курсор у поле пошуку",
     "Mark current article's feed/folder read" : "Зробити поточну подачу/теку артиклю лише для читання",
     "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
     "Subscribe" : "Підписатися",
