@@ -6,9 +6,11 @@ OC.L10N.register(
     "Download" : "Tải về",
     "Close" : "Đóng",
     "Open website" : "Mở trang web",
+    "Share" : "Chia sẻ",
     "Username" : "Tên đăng nhập",
     "by" : "bởi",
     "from" : "từ",
+    "Keyboard shortcut" : "Phím tắt",
     "Description" : "Mô tả",
     "right" : "phải",
     "left" : "trái",
@@ -26,6 +28,7 @@ OC.L10N.register(
     "Password" : "Mật khẩu",
     "Create" : "Tạo",
     "Rename" : "Sửa tên",
+    "Mark read" : "Đánh dấu là đã đọc",
     "Newest first" : "Mới trước",
     "Oldest first" : "Cũ trước",
     "Delete" : "Xóa",
