@@ -1,7 +1,7 @@
 <li class="add-new">
     <div class="heading">
         <button
-            class="icon-add"
+            class="icon-add-folder"
             data-apps-slide-toggle="#new-folder"
             news-focus="#new-folder [name='folderName']">
                 <?php p($l->t('New Folder'))?>
